@@ -2,6 +2,7 @@ import os.path
 import shlex
 import sys
 import time
+from typing import MutableMapping
 from unittest import mock
 
 import pytest
@@ -18,7 +19,6 @@ from pre_commit.commands.run import Classifier
 from pre_commit.commands.run import filter_by_include_exclude
 from pre_commit.commands.run import run
 from pre_commit.util import cmd_output
-from pre_commit.util import EnvironT
 from pre_commit.util import make_executable
 from testing.auto_namedtuple import auto_namedtuple
 from testing.fixtures import add_config_to_repo
@@ -219,6 +219,19 @@ def test_types_hook_repository(cap_out, store, tempdir_factory):
         assert b'bar.notpy' not in printed
 
 
+def test_types_or_hook_repository(cap_out, store, tempdir_factory):
+    git_path = make_consuming_repo(tempdir_factory, 'types_or_repo')
+    with cwd(git_path):
+        stage_a_file('bar.notpy')
+        stage_a_file('bar.pxd')
+        stage_a_file('bar.py')
+        ret, printed = _do_run(cap_out, store, git_path, run_opts())
+        assert ret == 1
+        assert b'bar.notpy' not in printed
+        assert b'bar.pxd' in printed
+        assert b'bar.py' in printed
+
+
 def test_exclude_types_hook_repository(cap_out, store, tempdir_factory):
     git_path = make_consuming_repo(tempdir_factory, 'exclude_types_repo')
     with cwd(git_path):
@@ -473,6 +486,7 @@ def test_from_ref_to_ref_error_msg_error(
 def test_all_push_options_ok(cap_out, store, repo_with_passing_hook):
     args = run_opts(
         from_ref='master', to_ref='master',
+        remote_branch='master',
         remote_name='origin', remote_url='https://example.com/repo',
     )
     ret, printed = _do_run(cap_out, store, repo_with_passing_hook, args)
@@ -482,7 +496,7 @@ def test_all_push_options_ok(cap_out, store, repo_with_passing_hook):
 
 def test_checkout_type(cap_out, store, repo_with_passing_hook):
     args = run_opts(from_ref='', to_ref='', checkout_type='1')
-    environ: EnvironT = {}
+    environ: MutableMapping[str, str] = {}
     ret, printed = _do_run(
         cap_out, store, repo_with_passing_hook, args, environ,
     )
@@ -951,6 +965,27 @@ def test_classifier_does_not_normalize_backslashes_non_windows(tmpdir):
                 assert classifier.filenames == [r'a/b\c']
 
 
+def test_classifier_empty_types_or(tmpdir):
+    tmpdir.join('bar').ensure()
+    os.symlink(tmpdir.join('bar'), tmpdir.join('foo'))
+    with tmpdir.as_cwd():
+        classifier = Classifier(('foo', 'bar'))
+        for_symlink = classifier.by_types(
+            classifier.filenames,
+            types=['symlink'],
+            types_or=[],
+            exclude_types=[],
+        )
+        for_file = classifier.by_types(
+            classifier.filenames,
+            types=['file'],
+            types_or=[],
+            exclude_types=[],
+        )
+        assert for_symlink == ['foo']
+        assert for_file == ['bar']
+
+
 @pytest.fixture
 def some_filenames():
     return (
@@ -1032,7 +1067,7 @@ def test_skipped_without_any_setup_for_post_checkout(in_git_dir, store):
 
 def test_pre_commit_env_variable_set(cap_out, store, repo_with_passing_hook):
     args = run_opts()
-    environ: EnvironT = {}
+    environ: MutableMapping[str, str] = {}
     ret, printed = _do_run(
         cap_out, store, repo_with_passing_hook, args, environ,
     )
