@@ -1,5 +1,4 @@
 import os.path
-import re
 import shutil
 import sys
 from typing import Any
@@ -8,8 +7,10 @@ from unittest import mock
 
 import cfgv
 import pytest
+import re_assert
 
 import pre_commit.constants as C
+from pre_commit import git
 from pre_commit.clientlib import CONFIG_SCHEMA
 from pre_commit.clientlib import load_manifest
 from pre_commit.envcontext import envcontext
@@ -31,6 +32,7 @@ from testing.fixtures import make_repo
 from testing.fixtures import modify_manifest
 from testing.util import cwd
 from testing.util import get_resource_path
+from testing.util import skipif_cant_run_coursier
 from testing.util import skipif_cant_run_docker
 from testing.util import skipif_cant_run_swift
 from testing.util import xfailif_windows
@@ -94,8 +96,8 @@ def test_conda_with_additional_dependencies_hook(tempdir_factory, store):
         config_kwargs={
             'hooks': [{
                 'id': 'additional-deps',
-                'args': ['-c', 'import mccabe; print("OK")'],
-                'additional_dependencies': ['mccabe'],
+                'args': ['-c', 'import tzdata; print("OK")'],
+                'additional_dependencies': ['python-tzdata'],
             }],
         },
     )
@@ -109,8 +111,8 @@ def test_local_conda_additional_dependencies(store):
             'name': 'local-conda',
             'entry': 'python',
             'language': 'conda',
-            'args': ['-c', 'import mccabe; print("OK")'],
-            'additional_dependencies': ['mccabe'],
+            'args': ['-c', 'import tzdata; print("OK")'],
+            'additional_dependencies': ['python-tzdata'],
         }],
     }
     hook = _get_hook(config, store, 'local-conda')
@@ -195,6 +197,15 @@ def test_versioned_python_hook(tempdir_factory, store):
     )
 
 
+@skipif_cant_run_coursier  # pragma: win32 no cover
+def test_run_a_coursier_hook(tempdir_factory, store):
+    _test_hook_repo(
+        tempdir_factory, store, 'coursier_hooks_repo',
+        'echo-java',
+        ['Hello World from coursier'], b'Hello World from coursier\n',
+    )
+
+
 @skipif_cant_run_docker  # pragma: win32 no cover
 def test_run_a_docker_hook(tempdir_factory, store):
     _test_hook_repo(
@@ -336,6 +347,59 @@ def test_golang_hook_still_works_when_gobin_is_set(tempdir_factory, store):
     assert os.listdir(gobin_dir) == []
 
 
+def test_golang_with_recursive_submodule(tmpdir, tempdir_factory, store):
+    sub_go = '''\
+package sub
+
+import "fmt"
+
+func Func() {
+    fmt.Println("hello hello world")
+}
+'''
+    sub = tmpdir.join('sub').ensure_dir()
+    sub.join('sub.go').write(sub_go)
+    cmd_output('git', '-C', str(sub), 'init', '.')
+    cmd_output('git', '-C', str(sub), 'add', '.')
+    git.commit(str(sub))
+
+    pre_commit_hooks = '''\
+-   id: example
+    name: example
+    entry: example
+    language: golang
+    verbose: true
+'''
+    go_mod = '''\
+module github.com/asottile/example
+
+go 1.14
+'''
+    main_go = '''\
+package main
+
+import "github.com/asottile/example/sub"
+
+func main() {
+    sub.Func()
+}
+'''
+    repo = tmpdir.join('repo').ensure_dir()
+    repo.join('.pre-commit-hooks.yaml').write(pre_commit_hooks)
+    repo.join('go.mod').write(go_mod)
+    repo.join('main.go').write(main_go)
+    cmd_output('git', '-C', str(repo), 'init', '.')
+    cmd_output('git', '-C', str(repo), 'add', '.')
+    cmd_output('git', '-C', str(repo), 'submodule', 'add', str(sub), 'sub')
+    git.commit(str(repo))
+
+    config = make_config_from_repo(str(repo))
+    hook = _get_hook(config, store, 'example')
+    ret, out = _hook_run(hook, (), color=False)
+    assert ret == 0
+    assert _norm_out(out) == b'hello hello world\n'
+
+
 def test_rust_hook(tempdir_factory, store):
     _test_hook_repo(
         tempdir_factory, store, 'rust_hooks_repo',
@@ -559,7 +623,7 @@ def test_additional_golang_dependencies_installed(
     path = make_repo(tempdir_factory, 'golang_hooks_repo')
     config = make_config_from_repo(path)
     # A small go package
-    deps = ['github.com/golang/example/hello']
+    deps = ['golang.org/x/example/hello']
     config['hooks'][0]['additional_dependencies'] = deps
     hook = _get_hook(config, store, 'golang-hook')
     binaries = os.listdir(
@@ -580,7 +644,7 @@ def test_local_golang_additional_dependencies(store):
             'name': 'hello',
             'entry': 'hello',
             'language': 'golang',
-            'additional_dependencies': ['github.com/golang/example/hello'],
+            'additional_dependencies': ['golang.org/x/example/hello'],
         }],
     }
     hook = _get_hook(config, store, 'hello')
@@ -630,7 +694,7 @@ def test_fail_hooks(store):
     )
 
 
-def test_unknown_keys(store, fake_log_handler):
+def test_unknown_keys(store, caplog):
     config = {
         'repo': 'local',
         'hooks': [{
@@ -643,8 +707,8 @@ def test_unknown_keys(store, fake_log_handler):
         }],
     }
     _get_hook(config, store, 'too-much')
-    expected = 'Unexpected key(s) present on local => too-much: foo, hello'
-    assert fake_log_handler.handle.call_args[0][0].msg == expected
+    msg, = caplog.messages
+    assert msg == 'Unexpected key(s) present on local => too-much: foo, hello'
 
 
 def test_reinstall(tempdir_factory, store, log_info_mock):
@@ -822,33 +886,34 @@ def test_default_stages(store, local_python_config):
     assert hook.stages == ['push']
 
 
-def test_hook_id_not_present(tempdir_factory, store, fake_log_handler):
+def test_hook_id_not_present(tempdir_factory, store, caplog):
     path = make_repo(tempdir_factory, 'script_hooks_repo')
     config = make_config_from_repo(path)
     config['hooks'][0]['id'] = 'i-dont-exist'
     with pytest.raises(SystemExit):
         _get_hook(config, store, 'i-dont-exist')
-    assert fake_log_handler.handle.call_args[0][0].msg == (
+    _, msg = caplog.messages
+    assert msg == (
         f'`i-dont-exist` is not present in repository file://{path}.  '
         f'Typo? Perhaps it is introduced in a newer version?  '
         f'Often `pre-commit autoupdate` fixes this.'
     )
 
 
-def test_too_new_version(tempdir_factory, store, fake_log_handler):
+def test_too_new_version(tempdir_factory, store, caplog):
     path = make_repo(tempdir_factory, 'script_hooks_repo')
     with modify_manifest(path) as manifest:
         manifest[0]['minimum_pre_commit_version'] = '999.0.0'
     config = make_config_from_repo(path)
     with pytest.raises(SystemExit):
         _get_hook(config, store, 'bash_hook')
-    msg = fake_log_handler.handle.call_args[0][0].msg
-    assert re.match(
+    _, msg = caplog.messages
+    pattern = re_assert.Matches(
         r'^The hook `bash_hook` requires pre-commit version 999\.0\.0 but '
         r'version \d+\.\d+\.\d+ is installed.  '
         r'Perhaps run `pip install --upgrade pre-commit`\.$',
-        msg,
     )
+    pattern.assert_matches(msg)
 
 
 @pytest.mark.parametrize('version', ('0.1.0', C.VERSION))
@@ -891,6 +956,7 @@ def test_manifest_hooks(tempdir_factory, store):
             'post-commit', 'manual', 'post-checkout', 'push',
         ),
         types=['file'],
+        types_or=[],
         verbose=False,
     )
 
@@ -917,3 +983,63 @@ def test_local_perl_additional_dependencies(store):
     ret, out = _hook_run(hook, (), color=False)
     assert ret == 0
     assert _norm_out(out).startswith(b'This is perltidy, v20200110')
+
+
+@pytest.mark.parametrize(
+    'repo',
+    (
+        'dotnet_hooks_csproj_repo',
+        'dotnet_hooks_sln_repo',
+    ),
+)
+def test_dotnet_hook(tempdir_factory, store, repo):
+    _test_hook_repo(
+        tempdir_factory, store, repo,
+        'dotnet example hook', [], b'Hello from dotnet!\n',
+    )
+
+
+def test_non_installable_hook_error_for_language_version(store, caplog):
+    config = {
+        'repo': 'local',
+        'hooks': [{
+            'id': 'system-hook',
+            'name': 'system-hook',
+            'language': 'system',
+            'entry': 'python3 -c "import sys; print(sys.version)"',
+            'language_version': 'python3.10',
+        }],
+    }
+    with pytest.raises(SystemExit) as excinfo:
+        _get_hook(config, store, 'system-hook')
+    assert excinfo.value.code == 1
+
+    msg, = caplog.messages
+    assert msg == (
+        'The hook `system-hook` specifies `language_version` but is using '
+        'language `system` which does not install an environment.  '
+        'Perhaps you meant to use a specific language?'
+    )
+
+
+def test_non_installable_hook_error_for_additional_dependencies(store, caplog):
+    config = {
+        'repo': 'local',
+        'hooks': [{
+            'id': 'system-hook',
+            'name': 'system-hook',
+            'language': 'system',
+            'entry': 'python3 -c "import sys; print(sys.version)"',
+            'additional_dependencies': ['astpretty'],
+        }],
+    }
+    with pytest.raises(SystemExit) as excinfo:
+        _get_hook(config, store, 'system-hook')
+    assert excinfo.value.code == 1
+
+    msg, = caplog.messages
+    assert msg == (
+        'The hook `system-hook` specifies `additional_dependencies` but is '
+        'using language `system` which does not install an environment.  '
+        'Perhaps you meant to use a specific language?'
+    )
